==> node-bubble-0.1.20.tgz: package/view/renderer.js <==
/**
 * HTML template renderer
 */

var configs = require("../conf/configs");
var RenderUtils = require("./render-utils");
var TagUtils = require("./tag-utils");
var StringUtils = require("./string-utils");

/**
 * Render HTML template
 *
 * @param {string} data - HTML template data
 * @param {object} model - Model used to render
 * @param {object} params - Query string object in URL
 * @param {string} viewPath - View page path
 *
 * @returns Object containing rendered data and render function cache
 */
function render(data, model, params, viewPath)
{
    var template = data.replace(/&gt;/g, ">").replace(/&lt;/g, "<").replace(/\r\n/g, "\n");
    var lines = template.split("\n");
    var buf = "var buf = '';\n";

    for (var i = 0; i < lines.length; i++) {
        // Evaluate line
        if (lines[i].indexOf("<!--[=") >= 0) {
            var textStart = 0;
            var textEnd;
            var d = "";

            do {
                textEnd = lines[i].indexOf("<!--[=", textStart);

                if (textEnd < 0) {
                    var oldStart = textStart;
                    textStart = lines[i].indexOf("]-->", oldStart);
                    if (textStart < 0) {
                        d += lines[i].substring(oldStart).replace(/\'/g, "\\'");
                        break;
                    }

                    d += lines[i].substring(textStart + 4).replace(/\'/g, "\\'");
                    break;
                }

                var text = lines[i].substring(textStart, textEnd).replace(/\'/g, "\\'");
                d += text + "<!--[=";

                textStart = lines[i].indexOf("]-->", textEnd) + 4;
                d += lines[i].substring(textEnd + 6, textStart);
            } while (textEnd >= 0);

            lines[i] = d;

            var p = lines[i].replace(/<\!--\[=(.*?)\]-->/g, "' + ($1) + '");

            if (p !== lines[i]) {
                buf += "buf += '" + p + "\\n';\n";
                continue;
            }
        }

        // Control line
        var p2 = lines[i].match(/<\!--\[(.*?)\]-->/);
        if (p2 !== null) {
            buf += p2[1] + "\n";
            continue;
        }

        // Unknown line, reserve
        buf += "buf += '" + lines[i].replace(/\'/g, "\\'") + "\\n';\n";
    }

    buf += "return buf;";

    // TODO: Deprecate parameter "Renderer" by "R" in future
    var renderFunction;

    try {
        /* jslint evil: true */
        renderFunction = new Function("model", "params", "context", "root", "Renderer", "R", "T", "S", buf);
    } catch (err) {
        console.error("Error occured when compiling template: ");
        console.dir(err);
        console.error("Current buffer: ");
        console.error(buf);
        console.error("Before compile: ");
        console.error(template);
    }

    var renderUtils = new RenderUtils(viewPath);
    var tagUtils = new TagUtils();
    var stringUtils = new StringUtils();

    // model and params are accessible
    return {
        cache: function (model, context, prefix) {
        	return renderFunction(model, context.params, context, prefix, renderUtils, renderUtils, tagUtils, stringUtils);
        }
    };
}

exports.render = render;

==> node-bubble-0.3.0.tgz: package/view/renderer.js <==
/**
 * HTML template renderer
 * 
 * NOTE: Deprecated in 0.2, please use renderer-async.js instead!
 */

var configs = require("../conf/configs");
var RenderUtils = require("./render-utils");
var TagUtils = require("./tag-utils");
var StringUtils = require("./string-utils");

/**
 * Render HTML template
 *
 * @param {string} data - HTML template data
 * @param {object} model - Model used to render
 * @param {object} params - Query string object in URL
 * @param {string} viewPath - View page path
 *
 * @returns Object containing rendered data and render function cache
 */
exports.render = (data, model, params, viewPath) =>
{
    var template = data.replace(/&gt;/g, ">").replace(/&lt;/g, "<").replace(/\r\n/g, "\n");
    var lines = template.split("\n");
    var buf = "var buf = '';\n";

    for (var i = 0; i < lines.length; i++) {
        // Evaluate line
        if (lines[i].indexOf("<!--[=") >= 0) {
            var textStart = 0;
            var textEnd;
            var d = "";

            do {
                textEnd = lines[i].indexOf("<!--[=", textStart);

                if (textEnd < 0) {
                    var oldStart = textStart;
                    textStart = lines[i].indexOf("]-->", oldStart);
                    if (textStart < 0) {
                        d += lines[i].substring(oldStart).replace(/\'/g, "\\'");
                        break;
                    }

                    d += lines[i].substring(textStart + 4).replace(/\'/g, "\\'");
                    break;
                }

                var text = lines[i].substring(textStart, textEnd).replace(/\'/g, "\\'");
                d += text + "<!--[=";

                textStart = lines[i].indexOf("]-->", textEnd) + 4;
                d += lines[i].substring(textEnd + 6, textStart);
            } while (textEnd >= 0);

            lines[i] = d;

            var p = lines[i].replace(/<\!--\[=(.*?)\]-->/g, "' + ($1) + '");

            if (p !== lines[i]) {
                buf += "buf += '" + p + "\\n';\n";
                continue;
            }
        }

        // Control line
        var p2 = lines[i].match(/<\!--\[(.*?)\]-->/);
        if (p2 !== null) {
            buf += p2[1] + "\n";
            continue;
        }

        // Unknown line, reserve
        buf += "buf += '" + lines[i].replace(/\'/g, "\\'") + "\\n';\n";
    }

    buf += "return buf;";

    // TODO: Deprecate parameter "Renderer" by "R" in future
    var renderFunction;

    try {
        /* jslint evil: true */
        renderFunction = new Function("model", "params", "context", "root", "Renderer", "R", "T", "S", buf);
    } catch (err) {
        console.error("Error occured when compiling template: ");
        console.dir(err);
        console.error("Current buffer: ");
        console.error(buf);
        console.error("Before compile: ");
        console.error(template);
    }

    var renderUtils = new RenderUtils(viewPath);
    var tagUtils = new TagUtils();
    var stringUtils = new StringUtils();

    // model and params are accessible
    return {
        cache: function (model, context, prefix) {
        	return renderFunction(model, context.params, context, prefix, renderUtils, renderUtils, tagUtils, stringUtils);
        }
    };
}
